package com.hw.dms.mapper;

import java.util.List;
import com.hw.dms.domain.DmsBaseDeviceParam;

/**
 * 设备参数信息Mapper接口
 * 
 * @author xins
 * @date 2024-01-09
 */
public interface DmsBaseDeviceParamMapper 
{
    /**
     * 查询设备参数信息
     * 
     * @param deviceParamId 设备参数信息主键
     * @return 设备参数信息
     */
    public DmsBaseDeviceParam selectDmsBaseDeviceParamByDeviceParamId(Long deviceParamId);

    /**
     * 查询设备参数信息列表
     * 
     * @param dmsBaseDeviceParam 设备参数信息
     * @return 设备参数信息集合
     */
    public List<DmsBaseDeviceParam> selectDmsBaseDeviceParamList(DmsBaseDeviceParam dmsBaseDeviceParam);

    /**
     * 新增设备参数信息
     * 
     * @param dmsBaseDeviceParam 设备参数信息
     * @return 结果
     */
    public int insertDmsBaseDeviceParam(DmsBaseDeviceParam dmsBaseDeviceParam);

    /**
     * 修改设备参数信息
     * 
     * @param dmsBaseDeviceParam 设备参数信息
     * @return 结果
     */
    public int updateDmsBaseDeviceParam(DmsBaseDeviceParam dmsBaseDeviceParam);

    /**
     * 删除设备参数信息
     * 
     * @param deviceParamId 设备参数信息主键
     * @return 结果
     */
    public int deleteDmsBaseDeviceParamByDeviceParamId(Long deviceParamId);

    /**
     * 批量删除设备参数信息
     * 
     * @param deviceParamIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDmsBaseDeviceParamByDeviceParamIds(Long[] deviceParamIds);
}
