package com.hw.dms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.dms.domain.DmsBaseDeviceParam;
import com.hw.dms.service.IDmsBaseDeviceParamService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 设备参数信息Controller
 * 
 * @author xins
 * @date 2024-01-09
 */
@RestController
@RequestMapping("/param")
public class DmsBaseDeviceParamController extends BaseController
{
    @Autowired
    private IDmsBaseDeviceParamService dmsBaseDeviceParamService;

    /**
     * 查询设备参数信息列表
     */
    @RequiresPermissions("dms:param:list")
    @GetMapping("/list")
    public TableDataInfo list(DmsBaseDeviceParam dmsBaseDeviceParam)
    {
        startPage();
        List<DmsBaseDeviceParam> list = dmsBaseDeviceParamService.selectDmsBaseDeviceParamList(dmsBaseDeviceParam);
        return getDataTable(list);
    }

    /**
     * 导出设备参数信息列表
     */
    @RequiresPermissions("dms:param:export")
    @Log(title = "设备参数信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsBaseDeviceParam dmsBaseDeviceParam)
    {
        List<DmsBaseDeviceParam> list = dmsBaseDeviceParamService.selectDmsBaseDeviceParamList(dmsBaseDeviceParam);
        ExcelUtil<DmsBaseDeviceParam> util = new ExcelUtil<DmsBaseDeviceParam>(DmsBaseDeviceParam.class);
        util.exportExcel(response, list, "设备参数信息数据");
    }

    /**
     * 获取设备参数信息详细信息
     */
    @RequiresPermissions("dms:param:query")
    @GetMapping(value = "/{deviceParamId}")
    public AjaxResult getInfo(@PathVariable("deviceParamId") Long deviceParamId)
    {
        return success(dmsBaseDeviceParamService.selectDmsBaseDeviceParamByDeviceParamId(deviceParamId));
    }

    /**
     * 新增设备参数信息
     */
    @RequiresPermissions("dms:param:add")
    @Log(title = "设备参数信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsBaseDeviceParam dmsBaseDeviceParam)
    {
        return toAjax(dmsBaseDeviceParamService.insertDmsBaseDeviceParam(dmsBaseDeviceParam));
    }

    /**
     * 修改设备参数信息
     */
    @RequiresPermissions("dms:param:edit")
    @Log(title = "设备参数信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsBaseDeviceParam dmsBaseDeviceParam)
    {
        return toAjax(dmsBaseDeviceParamService.updateDmsBaseDeviceParam(dmsBaseDeviceParam));
    }

    /**
     * 删除设备参数信息
     */
    @RequiresPermissions("dms:param:remove")
    @Log(title = "设备参数信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{deviceParamIds}")
    public AjaxResult remove(@PathVariable Long[] deviceParamIds)
    {
        return toAjax(dmsBaseDeviceParamService.deleteDmsBaseDeviceParamByDeviceParamIds(deviceParamIds));
    }
}
